@@ -25,15 +25,12 @@
 
 #include <glib-object.h>
 
+#include "goaprovider-priv.h"
+
 G_BEGIN_DECLS
 
 #define GOA_TYPE_EXCHANGE_PROVIDER   (goa_exchange_provider_get_type ())
-#define GOA_EXCHANGE_PROVIDER(o)     (G_TYPE_CHECK_INSTANCE_CAST ((o), GOA_TYPE_EXCHANGE_PROVIDER, GoaExchangeProvider))
-#define GOA_IS_EXCHANGE_PROVIDER(o)  (G_TYPE_CHECK_INSTANCE_TYPE ((o), GOA_TYPE_EXCHANGE_PROVIDER))
-
-typedef struct _GoaExchangeProvider GoaExchangeProvider;
-
-GType goa_exchange_provider_get_type (void) G_GNUC_CONST;
+G_DECLARE_FINAL_TYPE (GoaExchangeProvider, goa_exchange_provider, GOA, EXCHANGE_PROVIDER, GoaProvider);
 
 G_END_DECLS
 
