@@ -25,15 +25,12 @@
 
 #include <glib-object.h>
 
+#include "goaoauth2provider-priv.h"
+
 G_BEGIN_DECLS
 
 #define GOA_TYPE_FACEBOOK_PROVIDER   (goa_facebook_provider_get_type ())
-#define GOA_FACEBOOK_PROVIDER(o)     (G_TYPE_CHECK_INSTANCE_CAST ((o), GOA_TYPE_FACEBOOK_PROVIDER, GoaFacebookProvider))
-#define GOA_IS_FACEBOOK_PROVIDER(o)  (G_TYPE_CHECK_INSTANCE_TYPE ((o), GOA_TYPE_FACEBOOK_PROVIDER))
-
-typedef struct _GoaFacebookProvider GoaFacebookProvider;
-
-GType goa_facebook_provider_get_type (void) G_GNUC_CONST;
+G_DECLARE_FINAL_TYPE (GoaFacebookProvider, goa_facebook_provider, GOA, FACEBOOK_PROVIDER, GoaOAuth2Provider);
 
 G_END_DECLS
 
