@@ -25,15 +25,12 @@
 
 #include <glib-object.h>
 
+#include "goaprovider-priv.h"
+
 G_BEGIN_DECLS
 
 #define GOA_TYPE_OWNCLOUD_PROVIDER   (goa_owncloud_provider_get_type ())
-#define GOA_OWNCLOUD_PROVIDER(o)     (G_TYPE_CHECK_INSTANCE_CAST ((o), GOA_TYPE_OWNCLOUD_PROVIDER, GoaOwncloudProvider))
-#define GOA_IS_OWNCLOUD_PROVIDER(o)  (G_TYPE_CHECK_INSTANCE_TYPE ((o), GOA_TYPE_OWNCLOUD_PROVIDER))
-
-typedef struct _GoaOwncloudProvider GoaOwncloudProvider;
-
-GType goa_owncloud_provider_get_type (void) G_GNUC_CONST;
+G_DECLARE_FINAL_TYPE (GoaOwncloudProvider, goa_owncloud_provider, GOA, OWNCLOUD_PROVIDER, GoaProvider);
 
 G_END_DECLS
 
